%define major 2
%define libname %mklibname %{name} %{major}
%define libnamedev %mklibname %{name} -d

Name:  pjproject
Version: 2.3
%define subrel 1
Release: %mkrel 1
Summary: Libraries for building embedded/non-embedded VoIP applications
Group: System/Libraries
License: GPLv2+
URL: http://www.pjsip.org

Source0: http://www.pjsip.org/release/%{version}/%{name}-%{version}.tar.bz2

# Tell the build system not to use most of the third_party directory
Patch1: pjproject_no_third_party.patch
# If video is disabled, don't bother with libyuv
Patch2: pjproject_fix_libyuv.patch
# Keep the .pc file clean
# see https://bugzilla.redhat.com/show_bug.cgi?id=728302#c66
Patch3: pjproject_fixup_pc_file.patch
# Fix endianness on ARM platforms
Patch4: pjproject_fix_arm.patch
# Add aarch64
Patch5: pjproject-aarch64.patch
# fix two security issues
Patch6: pjproject-2.5.5-CVE-2017-9359_CVE-2017-9372.patch

BuildRequires: alsa-lib-devel
BuildRequires: gsm-devel
BuildRequires: libsrtp-devel
BuildRequires: libuuid-devel
BuildRequires: openssl-devel
BuildRequires: pkgconfig
BuildRequires: portaudio-devel
BuildRequires: speex-devel


%description
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications. 
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA


%package -n %{libname}
Summary: Libraries for building embedded/non-embedded VoIP applications
Group: System/Libraries

%description -n %{libname}
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications. 
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA

This package contains the shared library part of ccrtp.

%package -n %{libnamedev}
Summary: Development files to use pjproject
Group: Development/Other
Provides: %{name}-devel = %{version}-%{release}
Requires: %{libname} = %{version}-%{release}


%description -n %{libnamedev}
Header information for:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library


%prep
%setup -q -n %{name}-%{version}
%apply_patches

# make sure we don't bundle these third-party libraries
# (They're excluded through ./configure, but this is an 
# additional safety net)
rm -rf third_party/BaseClasses
rm -rf third_party/bdsound
rm -rf third_party/bin
rm -rf third_party/g7221
rm -rf third_party/gsm
rm -rf third_party/milenage
rm -rf third_party/mp3
rm -rf third_party/portaudio
rm -rf third_party/resample
rm -rf third_party/speex
rm -rf third_party/srtp
rm -rf third_party/ilbc
rm -rf third_party/build/baseclasses
rm -rf third_party/build/g7221
rm -rf third_party/build/gsm
rm -rf third_party/build/milenage
rm -rf third_party/build/portaudio/src
rm -rf third_party/build/resample
rm -rf third_party/build/samplerate
rm -rf third_party/build/speex
rm -rf third_party/build/srtp
rm -rf third_party/build/ilbc

%build

# We're building without audio or video support, as Asterisk isn't using
# that functionality, and it made it easier to ensure that we don't 
# bundle any unnecessary libraries.  Please contact me if your project
# needs this support, and I'll re-enable it
export CFLAGS="-DPJ_HAS_IPV6=1 ${ARCHFLAGS} %{optflags}"

%configure2_5x \
	--enable-shared        \
	--with-external-gsm    \
	--with-external-pa     \
	--with-external-speex  \
	--with-external-srtp   \
	--disable-opencore-amr \
	--disable-resample     \
	--disable-sound        \
	--disable-video        \
	--disable-v4l2         \
	--disable-ilbc-codec   \
	--without-libyuv       \
	--disable-g7221-codec  

%make dep
%make


%install
%makeinstall_std

# Remove the static libraries, as they aren't wanted
rm -f %{buildroot}%{_libdir}/libpj*.a

# rpmlint complains that this is an empty file, so let's fix that
echo -e '\n' >> %{buildroot}%{_includedir}/pj/config_site.h


%files -n %{libname}
%doc README.txt README-RTEMS INSTALL.txt COPYING
%{_libdir}/lib*.so.*

%files -n %{libnamedev}
%{_libdir}/lib*.so
%{_includedir}/pj++/
%{_includedir}/pj/
%{_includedir}/pjlib-util/
%{_includedir}/pjmedia-audiodev/
%{_includedir}/pjmedia-codec/
%{_includedir}/pjmedia-videodev/
%{_includedir}/pjmedia/
%{_includedir}/pjnath/
%{_includedir}/pjsip-simple/
%{_includedir}/pjsip-ua/
%{_includedir}/pjsip/
%{_includedir}/pjsua-lib/
%{_includedir}/pjsua2/
%{_includedir}/*.h
%{_includedir}/*.hpp
%{_libdir}/pkgconfig/libpjproject.pc



%changelog
* Sat Aug 12 2017 daviddavid <daviddavid> 2.3-1.1.mga5
+ Revision: 1139889
- add and rediff upstream patch to fix CVE-2017-9359 and CVE-2017-9372 (mga#21505)

* Sun Feb 08 2015 alien <alien> 2.3-1.mga5
+ Revision: 814093
- imported package pjproject

